@@ -1,9 +1,9 @@
-'''
+"""
 Python mapping for the CryptoTokenKit framework.
 
 This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
-'''
+"""
 
 import objc
 import sys
@@ -12,16 +12,21 @@ import Foundation
 from CryptoTokenKit import _metadata
 from CryptoTokenKit._CryptoTokenKit import *
 
-sys.modules['CryptoTokenKit'] = mod = objc.ObjCLazyModule(
+sys.modules["CryptoTokenKit"] = mod = objc.ObjCLazyModule(
     "CryptoTokenKit",
     "com.apple.CryptoTokenKit",
     objc.pathForFramework("/System/Library/Frameworks/CryptoTokenKit.framework"),
-    _metadata.__dict__, None, {
-        '__doc__': __doc__,
-        'objc': objc,
-        '__path__': __path__,
-        '__loader__': globals().get('__loader__', None),
-    }, (Foundation,))
+    _metadata.__dict__,
+    None,
+    {
+        "__doc__": __doc__,
+        "objc": objc,
+        "__path__": __path__,
+        "__loader__": globals().get("__loader__", None),
+    },
+    (Foundation,),
+)
 
 import sys
-del sys.modules['CryptoTokenKit._metadata']
+
+del sys.modules["CryptoTokenKit._metadata"]
